; 2002 Jensen Precast
;returns denominator of plot scale in multiples of sheet size
(defun sc ()
  (if (> (getvar "tilemode") 0)
    (/
      (if
        (or
          (and (sheetsize)(not (orientation)))
          (and (not (sheetsize))(orientation))
        )
        (cadr (limsize))
        (car (limsize)))
      11.0)
    1.0
  )
)

;returns T for "A" or nil for "B" paper size in multiples of limits
(defun sheetsize ()
  (apply '(lambda (x y)(not (equal x y 0.0625)))
    (mapcar '(lambda (x y)(/ x y))
      (limsize)
      (if (orientation)'(17.0 11.0)'(11.0 17.0))
    )
  )
)

;returns relative area of limits
(defun limsize ()
  (mapcar '- (getvar "limmax")(getvar "limmin"))
)

;returns 1 for landscape, else 0
(defun rotation (/ actlay)
  (setq actlay (alay))
  (vla-RefreshPlotDeviceInfo actlay)
  (> (vla-get-PlotRotation (alay)) 0)
)

;returns T for landscape, else nil
(defun orientation ()
  (apply '> (mapcar '- (limsize)(getvar "limmin")))
)

(defun ori ()
  (if (orientation) "Landscape" "Portrait")
)

(defun sheet ()
  (cond
    ( (and (sheetsize)(orientation)) '(11.0 8.5))
    ( (sheetsize) '(8.5 11.0))
    ( (orientation) '(17.0 11.0))
    ( T '(11.0 17.0))
  )
)

(defun size ()
  (if (sheetsize) "Letter" "Ledger")
)

(defun limits ()
  (list (getvar "limmin")(getvar "limmax"))
)

(defun GetLimits ()
  (vlax-safearray->list
    (vlax-variant-value
      (vla-get-limits (adoc))
    )
  )
)

(defun GetMediaName (/ actlay)
  (setq actlay (alay))
  (vla-RefreshPlotDeviceInfo actlay)
  (vla-GetLocaleMediaName actlay (vla-get-CanonicalMediaName actlay))
)

(defun GetPaperMargins (/ mx my)
  (vla-GetPaperMargins (alay) 'mx 'my)
  (mapcar 'vlax-safearray->list (list mx my))
)

(defun GetPaperSize (/ x y)
  (vla-GetPaperSize (alay) 'x 'y)
  (mapcar 'mm->in (list x y))
)

(defun mm->in (x)(/ x 25.4))

;returns media name based on a list of LL and UR coordinates
(defun af:sheet (e / n)
  (setq n (GetCanonicalMediaNames (adoc)))
  (car
    (vl-remove-if-not '(lambda (x)(member x n))
      (if (af:size e)
        '("Letter" "8.5x11" "8.5\"x11\"" "8.5 x 11" "8.5\" x 11\"" "8 1/2x11" "8 1/2\"x11\"" "8 1/2 x 11" "8 1/2\" x 11\"" "8-1/2x11" "8-1/2\"x11\"" "8-1/2 x 11" "8-1/2\" x 11\"")
        '("Tabloid" "User119" "User151" "11x17" "11 x 17" "11\"x17\"" "11 x 17" "11\" x 17\"")
      )
    )
  )
)

;Jimmy B
(defun GetCanonicalMediaNames (ad)
  (vla-RefreshPlotDeviceInfo
    (vla-get-activelayout
      ad))
  (vlax-safearray->list
    (vlax-variant-value
      (vla-GetCanonicalMediaNames
        (vla-item (vla-get-layouts ad) "Model"))))
)

